{% if config_system == "hydra" -%}
seed: 42
dataset_path: ${oc.env:PWD}/data/demo.csv
target: target
test_size: 0.2
model: random_forest  # random_forest | gradient_boosting
rf:
  n_estimators: 200
  max_depth: 12
gb:
  n_estimators: 400
  learning_rate: 0.05
{%- else -%}
{{ SKIP_FILE }}
{%- endif %}
