{% if config_system == "plain-yaml" -%}
train:
  seed: 42
  dataset_path: data/demo.csv    # will be auto-created by script if missing
  target: target
  test_size: 0.2
  model: random_forest           # random_forest | gradient_boosting
  rf:
    n_estimators: 200
    max_depth: 12
  gb:
    n_estimators: 400
    learning_rate: 0.05
eval:
  calibration_bins: 10

{% elif config_system == "hydra" -%}
defaults:
  - train: default
  - eval: default
  - _self_

project:
  name: "{{ repo_name }}"
  pkg: "{{ pkg }}"
tracking: "{{ tracking }}"

{% else -%}
{{ SKIP_FILE }}
{% endif %}
