from __future__ import annotations
from rich.console import Console

_console = Console()

def log(msg: str) -> None:
    # Use a Rich style with cyan bold for log messages
    _console.print(f"[bold cyan]{% raw %}{msg}{% endraw %}[/]")
