from __future__ import annotations
from pathlib import Path
ROOT = Path(__file__).resolve().parents[3]  # .../src/{{pkg}}/utils -> repo root
DATA_DIR = ROOT / "data"
ARTIFACTS_DIR = ROOT / "artifacts"
ARTIFACTS_DIR.mkdir(parents=True, exist_ok=True)
